@@ -6,15 +6,15 @@ use warnings;
 
 =head1 NAME
 
-Github::Fork::Parent - Perl module to determine which repository stands in a root of GitHub forking hierarhy.
+Github::Fork::Parent - Perl module to determine which repository stands in a root of GitHub forking hierarchy.
 
 =head1 VERSION
 
-Version 0.24
+Version 1.0
 
 =cut
 
-our $VERSION = '0.24';
+our $VERSION = '1.0';
 
 
 =head1 SYNOPSIS
@@ -63,7 +63,12 @@ sub get_repo_data {
 
 sub parse_github_links {
   my $link=shift;
-  if ($link=~m#^(?:\Qgit://github.com/\E|git\@github\.com:|https?://github\.com/)([^/]+)/([^/.]+)(?:\.git)?$#) {
+  $link =~ s/\.git$//; #github does not allow repositories ending in .git, so we can safely remove extension
+  if ($link=~m{^
+    (?:\Qgit://github.com/\E|git\@github\.com:|https?://github\.com/)
+    ([^/]+)/([^/]+) #repository name can contain dots
+    $ }x 
+  ) {
     return ($1,$2);
   } else {
     return (undef,undef);
@@ -159,7 +164,7 @@ Net::GitHub
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2016 Alexandr Ciornii.
+Copyright 2009-2017 Alexandr Ciornii.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
